@@ -293,7 +293,7 @@ class GeneratedsSuper(object):
                 raise_parse_error(node, 'Requires sequence of decimal values')
         return values
     def gds_format_double(self, input_data, input_name=''):
-        return '%e' % input_data
+        return '%s' % input_data
     def gds_parse_double(self, input_data, node=None, input_name=''):
         try:
             fval_ = float(input_data)
