@@ -2,7 +2,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.8.3 (default, Jul  2 2020, 16:21:59)  [GCC 7.3.0]
+# Python 3.8.5 (default, Sep  4 2020, 07:30:14)  [GCC 7.3.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -74,6 +74,13 @@ supermod.PersonType.subclass = PersonTypeSub
 # end class PersonTypeSub
 
 
+class PersonIdTypeSub(supermod.PersonIdType):
+    def __init__(self, valueOf_=None, **kwargs_):
+        super(PersonIdTypeSub, self).__init__(valueOf_,  **kwargs_)
+supermod.PersonIdType.subclass = PersonIdTypeSub
+# end class PersonIdTypeSub
+
+
 def get_root_tag(node):
     tag = supermod.Tag_pattern_.match(node.tag).groups()[-1]
     rootClass = None
